//Game.h//

#ifndef __GAME_H
#define __GAME_H

#include <vector>
#include "Board.h"
#include "Player.h"
#include "Die.h"

/** @brief the game class
 */
class Game
{
  public:
    /// construct the game
    Game();

    /// add a player to the game
    void AddPlayer(char cID, string oStrName);

    /// delete a player
    void DelPlayer(char cID);

    /// run the game
    void Start (void);

    /// stop the game
    void Stop (void);

    /// make a single move
    void Play (int iMoves=-1);
    
    /// load a board
    void Load (const string& rkostrBName);

    /// load an empty board
    void LoadEmpty (void);
    
    /// get the current player
    const Player& GetCurrPlayer (void);

    /// returns if game is started
    bool IsStarted(void);
    
    /// get the board within this game
    Board *GetBoard (void) { return m_poBoard; }
    
    /// get the die within this game
    Die *GetDie (void) { return &m_oDie; }

    /// get the players
    vector< Player > *GetPlayers (void) { return &m_oVecPlayers; }
    
  private:
    /// the board loaded within the game
    Board *m_poBoard;

    /// players in this game
    vector< Player > m_oVecPlayers;

    /// the die
    Die m_oDie;

    /// whether the game is started
    bool m_bStarted;

    /// current player
    int m_iCurrPlayer;
};

#endif //__GAME_H

//Game.h//
