// MenuWidget.cpp //

#include "MenuWidget.h"
#include "UI.h"

MenuWidget::MenuWidget (int iYPos, int iXPos, const string oStrTitle
    , const vector< string >& rkoVecStrEntries) 
: m_oVecStrEntries(rkoVecStrEntries)
, Widget (rkoVecStrEntries.size()+3, MenuWidth(rkoVecStrEntries,oStrTitle)+2, iYPos, iXPos, false) 
{
  keypad(m_poWin, true);
  m_iSelection = 0;
  m_oStrTitle = oStrTitle;
}

int MenuWidget::GetWidth (void)
{
  return MenuWidth(m_oVecStrEntries,m_oStrTitle);
}

int MenuWidget::MenuWidth (const vector< string >& rkoVecStrEntries, 
    const string oStrTitle)
{
  if (rkoVecStrEntries.size())
  {
    vector< string >::const_iterator oIter = rkoVecStrEntries.begin();
    int iMaxWidth = oIter->length();
    oIter++;
    for(;oIter != rkoVecStrEntries.end(); oIter++)
    {
      if (iMaxWidth < oIter->length())
      {
        iMaxWidth = oIter->length();
      }
    }
    if (oStrTitle.length() > iMaxWidth)
    {
      iMaxWidth = oStrTitle.length();
    }
    return iMaxWidth;
  }
  else
  {
    return 0;
  }
}

void MenuWidget::Draw (void)
{
  int iAttri = COLOR_PAIR(COLORPAIR_6)|WA_BOLD;
  wattron(m_poWin,iAttri);
  string oStrEntry;
  oStrEntry += " " + m_oStrTitle;
//  cerr << GetWidth();
  while (oStrEntry.length() < GetWidth()+1)
  {
    oStrEntry += ' ';
  }
  oStrEntry += " ";
  AddStr(0, 0, oStrEntry);
  
  oStrEntry = "";
  oStrEntry += "+";
  while (oStrEntry.length() < GetWidth()+1)
  {
    oStrEntry += '-';
  }
  oStrEntry += "+";
  AddStr(1, 0, oStrEntry);
  
  for (int i=0; i<m_oVecStrEntries.size(); i++)
  {
    oStrEntry = "";
    if (i == m_iSelection)
    {
      oStrEntry += "<" + m_oVecStrEntries[i];
    }
    else
    {
      oStrEntry += "|" + m_oVecStrEntries[i];
    }
    while (oStrEntry.length() < GetWidth()+1)
    {
      oStrEntry += ' ';
    }
    if (i == m_iSelection)
    {
      oStrEntry += ">";
    }
    else
    {
      oStrEntry += "|";
    }
    AddStr(i+2, 0, oStrEntry);
  }
  
  oStrEntry = "";
  oStrEntry += "+";
  while (oStrEntry.length() < GetWidth()+1)
  {
    oStrEntry += '-';
  }
  oStrEntry += "+";
  AddStr(m_oVecStrEntries.size()+2, 0, oStrEntry);
  wattroff(m_poWin,iAttri);
}

int MenuWidget::KeyFocus (void)
{
  Top();
  UI::Instance()->Status("Arrows to change select, <ENTER> to select.");

  while (true)
  {
    curs_set(0);
    int iCh = GetCh(0, 0);
    switch (iCh)
    {
      case KEY_UP:
        m_iSelection = (m_oVecStrEntries.size() + m_iSelection-1) % 
          (m_oVecStrEntries.size());
        Render();
        break;

      case KEY_DOWN:
        m_iSelection = (m_iSelection+1)%(m_oVecStrEntries.size());
        Render();
        break;

      case 10:
      case 27:
      case KEY_LEFT:
      case KEY_RIGHT:
        return iCh;
        break;

      default:
        UI::Instance()->Status("Invalid key pressed");
        break;
    }
  }
  return 0;
}

const string& MenuWidget::Selection (void)
{
  return m_oVecStrEntries[m_iSelection];
}

void MenuWidget::SetPrevMenu(MenuWidget *oMenuWid)
{
  m_poMenuWidPrev = oMenuWid;
}

void MenuWidget::SetNextMenu(MenuWidget *oMenuWid)
{
  m_poMenuWidNext = oMenuWid;
}

MenuWidget* MenuWidget::GetPrevMenu(void)
{
  return m_poMenuWidPrev;
}

MenuWidget* MenuWidget::GetNextMenu(void)
{
  return m_poMenuWidNext;
}
            
// MenuWidget.cpp //
