// UI.h //

#ifndef __UI_H
#define __UI_H

#include "Game.h"
#include "DieWidget.h"
#include "BoardWidget.h"
#include "PlayerWidget.h"
#include "StatusWidget.h"
#include "MenuWidget.h"
#include "BoardFactory.h"

class UI
{
  public:
    /// Initializer instance method
    static UI *Instance (Game *poGame);
    
    /// access instance
    static UI *Instance (void);

    /// destroy the UI
    static void Destroy (void);
    
    /// run the UI
    void Run (void);

    /// refresh the UI
    void Refresh (void);

    /// update the status
    void Status (const string& rkoStrMsg);

    /// Show the last move
    void ShowLastMove (void);

    /// Prompt the next player to throw a die
    void PromptNextMove (void);

  protected:
    /// constructor takes a pointer to the core game object
    UI (Game *poGame);

    /// destructor
    ~UI (void);

  private:
    /// the singleton UI instance
    static UI *c_poUI;
    
    /// the core game class
    Game *m_poGame;

    /// panels within this UI

    /// the board widget
    BoardWidget *m_poBoardWid;
    
    /// the player widget
    PlayerWidget *m_poPlayerWid;
    
    /// the die widget
    DieWidget *m_poDieWid;

    /// the status widget
    StatusWidget *m_poStatusWid;

    /// the Menu widget
    MenuWidget *m_poMenuWid1;

    /// the menu widget
    MenuWidget *m_poMenuWid2;

    /// the menu widget
    MenuWidget *m_poMenuWid3;
};

#endif //__UI_H

// UI.h //
