// Widget.cpp//

#include "ui_ex.h"
#include "Widget.h"

Widget::Widget (int iYSize, int iXSize, int iYPosn, int iXPosn
    , bool bHasBorder)
{
  init_pair(COLORPAIR_1,COLOR_WHITE, COLOR_BLACK);
  init_pair(COLORPAIR_2,COLOR_BLACK, COLOR_WHITE);
  init_pair(COLORPAIR_3,COLOR_RED, COLOR_BLACK);
  init_pair(COLORPAIR_4,COLOR_GREEN, COLOR_BLACK);
  init_pair(COLORPAIR_5,COLOR_CYAN, COLOR_BLACK);
  init_pair(COLORPAIR_6,COLOR_MAGENTA, COLOR_BLACK);

  m_iYSize = iYSize;
  m_iXSize = iXSize;
  m_iYPosn = iYPosn;
  m_iXPosn = iXPosn;
  m_bHasBorder = bHasBorder;

  m_poWin = newwin (m_iYSize, m_iXSize, m_iYPosn, m_iXPosn);
  if (NULL == m_poWin)
  {
    throw FailedNewWin();
  }
  m_poPanel = new_panel(m_poWin);
  if (NULL == m_poPanel)
  {
    delwin(m_poWin);
    throw FailedNewWin();
  }
}

Widget::~Widget (void)
{
  del_panel(m_poPanel);
  delwin(m_poWin);
}

void Widget::Render (void)
{
  if (m_bHasBorder)
  {
    wborder(m_poWin, '|', '|', '-', '-', '+', '+', '+', '+');
  }
  this->Draw();
  Refresh();
}

void Widget::AddStr(int iYPos, int iXPos, const string& rkoStrText)
{
  if (m_bHasBorder)
  {
    mvwaddstr(m_poWin, iYPos+1, iXPos+1, rkoStrText.c_str());
  }
  else
  {
    mvwaddstr(m_poWin, iYPos, iXPos, rkoStrText.c_str());
  }
}

void Widget::HLine(int iYPos)
{
  if (m_bHasBorder)
  {
    mvwhline(m_poWin, iYPos+1, 1, '-', m_iXSize-2);
  }
  else
  {
    mvwhline(m_poWin, iYPos, 1, '-', m_iXSize-2);
  }
}

void Widget::VLine(int iXPos)
{
  if (m_bHasBorder)
  {
    mvwvline(m_poWin, 1, iXPos+1, '|', m_iYSize-2);
  }
  else
  {
    mvwvline(m_poWin, 1, iXPos, '|', m_iYSize-2);
  }
}

int Widget::GetCh (int iYPos, int iXPos)
{
  int iCh;

  if (m_bHasBorder)
  {
    iCh=mvwgetch(m_poWin, iYPos+1, iXPos+1);
  }
  else
  {
    iCh=mvwgetch(m_poWin, iYPos, iXPos);
  }
  return iCh;
}

/// bring this window to the top
void Widget::Top (void)
{
  top_panel(m_poPanel);
}

/// hide this window
void Widget::Hide (void)
{
  hide_panel(m_poPanel);
}

/// show this panel
void Widget::Show (void)
{
  show_panel(m_poPanel);
}

void Widget :: DrawBitmap (const string& rkostrBitMap, int iAttri)
{
  int iXSize = m_iXSize-2;
  int iYSize = m_iYSize-1;

  wattron(m_poWin,iAttri);
  int x=0, y=0;
  for (; (y<iYSize) && (x+iXSize < rkostrBitMap.size()); y++)
  {
    AddStr(y, 0, rkostrBitMap.substr(x, iXSize));
    x +=iXSize;
  }
  wattroff(m_poWin,iAttri);
}

// Widget.cpp//
